@@ -4,7 +4,7 @@
 #  specific sets of holidays on the fly. It aims to make determining whether a
 #  specific date is a holiday as fast and flexible as possible.
 #
-#  Authors: Vacanza Team and individual contributors (see AUTHORS.md file)
+#  Authors: Vacanza Team and individual contributors (see CONTRIBUTORS file)
 #           dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
 #           ryanss <ryanssdev@icloud.com> (c) 2014-2017
 #  Website: https://github.com/vacanza/holidays
@@ -16,6 +16,10 @@ from typing import Optional
 from holidays.calendars.custom import _CustomCalendar
 from holidays.calendars.gregorian import JAN, FEB, MAR, APR, MAY, JUN, SEP, OCT, NOV
 
+CHINESE_CALENDAR = "CHINESE_CALENDAR"
+KOREAN_CALENDAR = "KOREAN_CALENDAR"
+VIETNAMESE_CALENDAR = "VIETNAMESE_CALENDAR"
+
 BUDDHA_BIRTHDAY = "BUDDHA_BIRTHDAY"
 DOUBLE_NINTH = "DOUBLE_NINTH"
 DRAGON_BOAT = "DRAGON_BOAT"
@@ -225,6 +229,7 @@ class _ChineseLunisolar:
         2097: (MAY, 19),
         2098: (MAY, 8),
         2099: (MAY, 27),
+        2100: (MAY, 16),
     }
 
     DOUBLE_NINTH_DATES = {
@@ -427,6 +432,7 @@ class _ChineseLunisolar:
         2097: (OCT, 13),
         2098: (OCT, 3),
         2099: (OCT, 22),
+        2100: (OCT, 12),
     }
 
     DRAGON_BOAT_DATES = {
@@ -629,6 +635,7 @@ class _ChineseLunisolar:
         2097: (JUN, 14),
         2098: (JUN, 4),
         2099: (JUN, 23),
+        2100: (JUN, 12),
     }
 
     HUNG_KINGS_DATES = {
@@ -831,6 +838,7 @@ class _ChineseLunisolar:
         2097: (APR, 21),
         2098: (APR, 11),
         2099: (APR, 29),
+        2100: (APR, 19),
     }
 
     LUNAR_NEW_YEAR_DATES = {
@@ -849,7 +857,7 @@ class _ChineseLunisolar:
         1913: (FEB, 6),
         1914: (JAN, 26),
         1915: (FEB, 14),
-        1916: (FEB, 3),
+        1916: (FEB, 4),
         1917: (JAN, 23),
         1918: (FEB, 11),
         1919: (FEB, 1),
@@ -1033,6 +1041,7 @@ class _ChineseLunisolar:
         2097: (FEB, 12),
         2098: (FEB, 1),
         2099: (JAN, 21),
+        2100: (FEB, 9),
     }
 
     MID_AUTUMN_DATES = {
@@ -1224,7 +1233,7 @@ class _ChineseLunisolar:
         2086: (SEP, 22),
         2087: (SEP, 11),
         2088: (SEP, 29),
-        2089: (SEP, 19),
+        2089: (SEP, 18),
         2090: (SEP, 8),
         2091: (SEP, 27),
         2092: (SEP, 16),
@@ -1235,16 +1244,95 @@ class _ChineseLunisolar:
         2097: (SEP, 20),
         2098: (SEP, 9),
         2099: (SEP, 29),
+        2100: (SEP, 18),
     }
 
-    def _get_holiday(self, holiday: str, year: int) -> tuple[Optional[date], bool]:
+    KOREAN_CALENDAR_BUDDHA_BIRTHDAY_DATES = {
+        1905: (MAY, 12),
+        1908: (MAY, 8),
+        1931: (MAY, 25),
+        1968: (MAY, 5),
+        2001: (MAY, 1),
+        2012: (MAY, 28),
+        2023: (MAY, 27),
+    }
+
+    KOREAN_CALENDAR_LUNAR_NEW_YEAR_DATES = {
+        1944: (JAN, 26),
+        1954: (FEB, 4),
+        1958: (FEB, 19),
+        1966: (JAN, 22),
+        1988: (FEB, 18),
+        1997: (FEB, 8),
+        2027: (FEB, 7),
+        2028: (JAN, 27),
+        2061: (JAN, 22),
+        2089: (FEB, 11),
+        2092: (FEB, 8),
+    }
+
+    KOREAN_CALENDAR_MID_AUTUMN_DATES = {
+        1909: (SEP, 29),
+        1942: (SEP, 25),
+        2040: (SEP, 21),
+        2089: (SEP, 19),
+        2096: (OCT, 1),
+        2098: (SEP, 10),
+    }
+
+    VIETNAMESE_CALENDAR_HUNG_KINGS_DATES = {
+        1916: (APR, 11),
+        1917: (APR, 1),
+        1939: (APR, 28),
+        1975: (APR, 20),
+        2009: (APR, 4),
+        2037: (APR, 24),
+        2038: (APR, 13),
+        2085: (APR, 3),
+        2086: (APR, 22),
+        2095: (APR, 13),
+        2100: (APR, 18),
+    }
+
+    VIETNAMESE_CALENDAR_LUNAR_NEW_YEAR_DATES = {
+        1903: (JAN, 28),
+        1916: (FEB, 3),
+        1935: (FEB, 3),
+        1965: (FEB, 1),
+        1968: (JAN, 29),
+        1969: (FEB, 16),
+        1985: (JAN, 21),
+        2007: (FEB, 17),
+        2030: (FEB, 2),
+        2053: (FEB, 18),
+    }
+
+    def __init__(self, calendar: str = CHINESE_CALENDAR) -> None:
+        self.__verify_calendar(calendar)
+        self.__calendar = calendar
+
+    @staticmethod
+    def __verify_calendar(calendar):
+        """Verify calendar type."""
+
+        supported_calendars = {CHINESE_CALENDAR, KOREAN_CALENDAR, VIETNAMESE_CALENDAR}
+        if calendar not in supported_calendars:
+            raise ValueError(
+                f"Unknown calendar name: {calendar}. "
+                f"Supported calendars: {', '.join(sorted(supported_calendars))}"
+            )
+
+    def _get_holiday(self, holiday: str, year: int, calendar=None) -> tuple[Optional[date], bool]:
+        calendar = calendar or self.__calendar
+        self.__verify_calendar(calendar)
+        custom_calendar_dates = getattr(self, f"{calendar}_{holiday}_DATES", {})
         estimated_dates = getattr(self, f"{holiday}_DATES", {})
         exact_dates = getattr(self, f"{holiday}_DATES_{_CustomCalendar.CUSTOM_ATTR_POSTFIX}", {})
-        dt = exact_dates.get(year, estimated_dates.get(year, ()))
+        dt = exact_dates.get(year, custom_calendar_dates.get(year, estimated_dates.get(year, ())))
         return date(year, *dt) if dt else None, year not in exact_dates
 
-    def buddha_birthday_date(self, year: int) -> tuple[Optional[date], bool]:
-        return self._get_holiday(BUDDHA_BIRTHDAY, year)
+    def buddha_birthday_date(self, year: int, calendar=None) -> tuple[Optional[date], bool]:
+        return self._get_holiday(BUDDHA_BIRTHDAY, year, calendar)
 
     def double_ninth_date(self, year: int) -> tuple[Optional[date], bool]:
         return self._get_holiday(DOUBLE_NINTH, year)
@@ -1252,14 +1340,14 @@ class _ChineseLunisolar:
     def dragon_boat_date(self, year: int) -> tuple[Optional[date], bool]:
         return self._get_holiday(DRAGON_BOAT, year)
 
-    def hung_kings_date(self, year: int) -> tuple[Optional[date], bool]:
-        return self._get_holiday(HUNG_KINGS, year)
+    def hung_kings_date(self, year: int, calendar=None) -> tuple[Optional[date], bool]:
+        return self._get_holiday(HUNG_KINGS, year, calendar)
 
-    def lunar_new_year_date(self, year: int) -> tuple[Optional[date], bool]:
-        return self._get_holiday(LUNAR_NEW_YEAR, year)
+    def lunar_new_year_date(self, year: int, calendar=None) -> tuple[Optional[date], bool]:
+        return self._get_holiday(LUNAR_NEW_YEAR, year, calendar)
 
-    def mid_autumn_date(self, year: int) -> tuple[Optional[date], bool]:
-        return self._get_holiday(MID_AUTUMN, year)
+    def mid_autumn_date(self, year: int, calendar=None) -> tuple[Optional[date], bool]:
+        return self._get_holiday(MID_AUTUMN, year, calendar)
 
 
 class _CustomChineseHolidays(_CustomCalendar, _ChineseLunisolar):
