@@ -4,7 +4,7 @@
 #  specific sets of holidays on the fly. It aims to make determining whether a
 #  specific date is a holiday as fast and flexible as possible.
 #
-#  Authors: Vacanza Team and individual contributors (see AUTHORS.md file)
+#  Authors: Vacanza Team and individual contributors (see CONTRIBUTORS file)
 #           dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
 #           ryanss <ryanssdev@icloud.com> (c) 2014-2017
 #  Website: https://github.com/vacanza/holidays
@@ -28,8 +28,8 @@ class Cameroon(
 
     References:
         * <https://en.wikipedia.org/wiki/Public_holidays_in_Cameroon>
-        * <https://www.timeanddate.com/holidays/cameroon>
-        * <https://www.officeholidays.com/countries/cameroon>
+        * <https://web.archive.org/web/20250408001410/https://www.timeanddate.com/holidays/cameroon/>
+        * <https://web.archive.org/web/20231004010829/https://www.officeholidays.com/countries/cameroon>
     """
 
     country = "CM"
@@ -37,7 +37,7 @@ class Cameroon(
     # On 1 January 1960, French Cameroun gained independence from France.
     start_year = 1960
 
-    def __init__(self, islamic_show_estimated: bool = True, *args, **kwargs):
+    def __init__(self, *args, islamic_show_estimated: bool = True, **kwargs):
         """
         Args:
             islamic_show_estimated:
