@@ -4,7 +4,7 @@
 #  specific sets of holidays on the fly. It aims to make determining whether a
 #  specific date is a holiday as fast and flexible as possible.
 #
-#  Authors: Vacanza Team and individual contributors (see AUTHORS.md file)
+#  Authors: Vacanza Team and individual contributors (see CONTRIBUTORS file)
 #           dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
 #           ryanss <ryanssdev@icloud.com> (c) 2014-2017
 #  Website: https://github.com/vacanza/holidays
@@ -31,20 +31,23 @@ class India(
     """India holidays.
 
     References:
-        * <https://www.india.gov.in/calendar>
-        * <https://www.india.gov.in/state-and-ut-holiday-calendar>
+        * <https://web.archive.org/web/20250413193616/https://www.india.gov.in/calendar>
+        * <https://web.archive.org/web/20250413193624/https://www.india.gov.in/state-and-ut-holiday-calendar>
         * <https://en.wikipedia.org/wiki/Public_holidays_in_India>
-        * <https://www.calendarlabs.com/holidays/india/2021>
-        * <https://slusi.dacnet.nic.in/watershedatlas/list_of_state_abbreviation.htm>
-        * <https://vahan.parivahan.gov.in/vahan4dashboard/>
+        * <https://web.archive.org/web/20250413193633/https://www.calendarlabs.com/holidays/india/2021>
+        * <https://web.archive.org/web/20231118175007/http://slusi.dacnet.nic.in/watershedatlas/list_of_state_abbreviation.htm>
+        * <https://web.archive.org/web/20231008063930/https://vahan.parivahan.gov.in/vahan4dashboard/>
+        * Tamil Nadu:
+            * [Tamil Monthly Calendar](https://web.archive.org/web/20231228103352/https://www.tamildailycalendar.com/tamil_monthly_calendar.php)
+            * [Tamil Calendar](https://web.archive.org/web/20250429125140/https://www.prokerala.com/general/calendar/tamilcalendar.php)
     """
 
     country = "IN"
     default_language = "en_IN"
     # %s (estimated).
     estimated_label = tr("%s (estimated)")
-    supported_categories = (OPTIONAL, PUBLIC)
-    supported_languages = ("en_IN", "en_US", "hi")
+    # India gained independence on August 15, 1947.
+    start_year = 1948
     subdivisions = (
         "AN",  # Andaman and Nicobar Islands.
         "AP",  # Andhra Pradesh.
@@ -83,10 +86,6 @@ class India(
         "UP",  # Uttar Pradesh.
         "WB",  # West Bengal.
     )
-    _deprecated_subdivisions = (
-        "DD",  # Daman and Diu.
-        "OR",  # Orissa.
-    )
     subdivisions_aliases = {
         "Andaman and Nicobar Islands": "AN",
         "Andhra Pradesh": "AP",
@@ -144,11 +143,14 @@ class India(
         "Uttar Pradesh": "UP",
         "West Bengal": "WB",
     }
+    supported_categories = (OPTIONAL, PUBLIC)
+    supported_languages = ("en_IN", "en_US", "hi")
+    _deprecated_subdivisions = (
+        "DD",  # Daman and Diu.
+        "OR",  # Orissa.
+    )
 
-    # India gained independence on August 15, 1947.
-    start_year = 1948
-
-    def __init__(self, islamic_show_estimated: bool = True, *args, **kwargs):
+    def __init__(self, *args, islamic_show_estimated: bool = True, **kwargs):
         """
         Args:
             islamic_show_estimated:
@@ -456,7 +458,11 @@ class India(
     # Tamil Nadu.
     def _populate_subdiv_tn_public_holidays(self):
         # Pongal.
-        self._add_makar_sankranti(tr("Pongal"))
+        self._add_pongal(tr("Pongal"))
+        # Thiruvalluvar Day / Mattu Pongal.
+        self._add_thiruvalluvar_day(tr("Thiruvalluvar Day / Mattu Pongal"))
+        # Uzhavar Thirunal.
+        self._add_uzhavar_thirunal(tr("Uzhavar Thirunal"))
         # Dr. B. R. Ambedkar Jayanti.
         self._add_holiday_apr_14(tr("Dr. B. R. Ambedkar's Jayanti"))
         # Puthandu.
