@@ -4,7 +4,7 @@
 #  specific sets of holidays on the fly. It aims to make determining whether a
 #  specific date is a holiday as fast and flexible as possible.
 #
-#  Authors: Vacanza Team and individual contributors (see AUTHORS.md file)
+#  Authors: Vacanza Team and individual contributors (see CONTRIBUTORS file)
 #           dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
 #           ryanss <ryanssdev@icloud.com> (c) 2014-2017
 #  Website: https://github.com/vacanza/holidays
@@ -24,18 +24,19 @@ class Pakistan(HolidayBase, InternationalHolidays, IslamicHolidays):
     References:
         * <https://en.wikipedia.org/wiki/Public_holidays_in_Pakistan>
         * <https://ur.wikipedia.org/wiki/تعطیلات_پاکستان>
-        * [Public and optional holidays](https://cabinet.gov.pk/Detail/OTE2ODBiYmItZmI0MS00NDAwLWE5NGUtYmE1MGVjYzllMzAz)
-        * [No.10-01/2024-Min-II](https://cabinet.gov.pk/SiteImage/Misc/files/Holidays/28-5-24.pdf)
+        * [Public and optional holidays](https://web.archive.org/web/20250118105814/https://cabinet.gov.pk/Detail/OTE2ODBiYmItZmI0MS00NDAwLWE5NGUtYmE1MGVjYzllMzAz)
+        * [No.10-01/2024-Min-II](https://web.archive.org/web/20241103080918/https://cabinet.gov.pk/SiteImage/Misc/files/Holidays/28-5-24.pdf)
     """
 
     country = "PK"
     default_language = "en_PK"
     # %s (estimated).
     estimated_label = tr("%s (estimated)")
+    # Achieved Independence on August 14th, 1947.
     start_year = 1948
     supported_languages = ("en_PK", "en_US", "ur_PK")
 
-    def __init__(self, islamic_show_estimated: bool = True, *args, **kwargs):
+    def __init__(self, *args, islamic_show_estimated: bool = True, **kwargs):
         """
         Args:
             islamic_show_estimated:
@@ -105,8 +106,7 @@ class PAK(Pakistan):
 
 
 class PakistanIslamicHolidays(_CustomIslamicHolidays):
-    # https://www.timeanddate.com/holidays/pakistan/first-day-ashura
-
+    # https://web.archive.org/web/20250724060822/https://www.timeanddate.com/holidays/pakistan/ashura
     ASHURA_DATES = {
         2005: (FEB, 18),
         2006: (FEB, 8),
@@ -128,9 +128,10 @@ class PakistanIslamicHolidays(_CustomIslamicHolidays):
         2022: (AUG, 9),
         2023: (JUL, 28),
         2024: (JUL, 16),
+        2025: (JUL, 6),
     }
 
-    # https://www.timeanddate.com/holidays/pakistan/eid-ul-azha
+    # https://web.archive.org/web/20250724060629/https://www.timeanddate.com/holidays/pakistan/eid-ul-azha
     EID_AL_ADHA_DATES = {
         2005: (JAN, 21),
         2006: ((JAN, 10), (DEC, 31)),
@@ -152,9 +153,10 @@ class PakistanIslamicHolidays(_CustomIslamicHolidays):
         2022: (JUL, 10),
         2023: (JUN, 29),
         2024: (JUN, 17),
+        2025: (JUN, 7),
     }
 
-    # https://www.timeanddate.com/holidays/pakistan/eid-ul-fitr-1
+    # https://web.archive.org/web/20250724060834/https://www.timeanddate.com/holidays/pakistan/eid-ul-fitr-1
     EID_AL_FITR_DATES = {
         2005: (NOV, 4),
         2006: (OCT, 24),
@@ -179,7 +181,7 @@ class PakistanIslamicHolidays(_CustomIslamicHolidays):
         2025: (MAR, 31),
     }
 
-    # https://www.timeanddate.com/holidays/pakistan/eid-milad-un-nabi
+    # https://web.archive.org/web/20250724061027/https://www.timeanddate.com/holidays/pakistan/eid-milad-un-nabi
     MAWLID_DATES = {
         2005: (APR, 22),
         2006: (APR, 11),
