@@ -4,7 +4,7 @@
 #  specific sets of holidays on the fly. It aims to make determining whether a
 #  specific date is a holiday as fast and flexible as possible.
 #
-#  Authors: Vacanza Team and individual contributors (see AUTHORS.md file)
+#  Authors: Vacanza Team and individual contributors (see CONTRIBUTORS file)
 #           dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
 #           ryanss <ryanssdev@icloud.com> (c) 2014-2017
 #  Website: https://github.com/vacanza/holidays
@@ -1262,6 +1262,10 @@ class TestWorkdays(unittest.TestCase):
         self.assertEqual(self.hb.get_nth_working_day("2024-05-10", -7), date(2024, 4, 29))
         self.assertEqual(self.hb.get_nth_working_day("2024-05-10", -5), date(2024, 5, 3))
 
+        self.assertEqual(self.hb.get_nth_working_day("2024-07-27", 0), date(2024, 7, 29))
+        self.assertEqual(self.hb.get_nth_working_day("2024-07-27", 1), date(2024, 7, 29))
+        self.assertEqual(self.hb.get_nth_working_day("2024-07-29", 0), date(2024, 7, 29))
+
     def test_get_working_days_count(self):
         self.assertEqual(self.hb.get_working_days_count("2024-01-03", "2024-01-23"), 15)
         self.assertEqual(self.hb.get_working_days_count("2024-01-23", "2024-01-03"), 15)
@@ -1286,12 +1290,12 @@ class TestClosestHoliday(unittest.TestCase):
         self.hb = CountryStub3(years=self.current_year)
         self.next_labor_day_year = (
             self.current_year
-            if datetime.now().date() < self.hb.get_named("Custom May 1st Holiday")[0]
+            if datetime.now().date() <= self.hb.get_named("Custom May 1st Holiday")[0]
             else self.next_year
         )
         self.previous_labor_day_year = (
             self.current_year
-            if datetime.now().date() > self.hb.get_named("Custom May 1st Holiday")[0]
+            if datetime.now().date() >= self.hb.get_named("Custom May 2nd Holiday")[0]
             else self.previous_year
         )
 
